#
# spec file for package gnome-calendar
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-calendar
Version:        42.2
Release:        bp155.1.6
Summary:        A calendar application for GNOME
License:        GPL-3.0-or-later
Group:          Productivity/Office/Organizers
URL:            https://wiki.gnome.org/Design/Apps/Calendar
Source0:        https://download.gnome.org/sources/gnome-calendar/42/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(geocode-glib-1.0) >= 3.23
BuildRequires:  pkgconfig(gio-2.0) >= 2.43.4
BuildRequires:  pkgconfig(glib-2.0) >= 2.43.4
BuildRequires:  pkgconfig(goa-1.0) >= 3.2.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.21.2
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(gweather4)
BuildRequires:  pkgconfig(libadwaita-1) >= 0.0.9
BuildRequires:  pkgconfig(libdazzle-1.0) >= 3.33.1
BuildRequires:  pkgconfig(libecal-2.0) >= 3.33.2
BuildRequires:  pkgconfig(libedataserver-1.2) >= 3.17.1
BuildRequires:  pkgconfig(libedataserverui-1.2) >= 3.17.1
BuildRequires:  pkgconfig(libgeoclue-2.0) >= 2.4
BuildRequires:  pkgconfig(libical) >= 3.0.5
BuildRequires:  pkgconfig(libsoup-2.4)

%description
Calendar is a calendar application for GNOME.

%package -n gnome-shell-search-provider-gnome-calendar
Summary:        GNOME Shell search provider to return results from the GNOME Calendar
Group:          Productivity/Office/Organizers
Requires:       %{name} = %{version}
Supplements:    (gnome-shell and %{name})

%description -n gnome-shell-search-provider-gnome-calendar
This package contains a search provider to enable GNOME Shell to get
search results from GNOME Calendar.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dtracing=false \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_prefix}

%check
%meson_test

%files
%license COPYING
%doc NEWS README.md TODO.md
%{_bindir}/gnome-calendar
%{_datadir}/applications/org.gnome.Calendar.desktop
# Own dir for openSUSE Leap 42.1
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Calendar.appdata.xml
%{_datadir}/dbus-1/services/org.gnome.Calendar.service
%{_datadir}/glib-2.0/schemas/org.gnome.calendar.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.calendar.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*.*

%files -n gnome-shell-search-provider-gnome-calendar
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Calendar.search-provider.ini

%files lang -f %{name}.lang

%changelog
* Wed Jun 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.2:
  + Fix AppData screenshots URLs.
  + Small bugfixes.
  + Improve support for right-to-left languages.
  + Updated translations.
* Wed Apr 27 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.1:
  + Improvements to the date chooser widget.
  + Fix spawning of Settings app.
  + Updated translations.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated translations.
* Tue Mar  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Fix a couple of regressions in the event importer dialog.
  + More timezone fixes when importing events.
  + Fix event times in event popover.
  + Updated translations.
* Tue Feb 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Port to GTK4
  + Rewrite the Year view to be a month nagivator
  + Various improvements to timezone handling
  + Update Ctrl+1/2/3 shortcuts to use Alt instead
- Drop e35dbc1acd03dd1751b755b6c8e1932a692ad4e1.patch: Fixed
  upstream.
- Replace the following BuildRequires:
  + pkgconfig(gtk+-3.0) with pkgconfig(gtk4)
  + pkgconfig(gweather-3.0) with pkgconfig(gweather4)
  + pkgconfig(libhandy-1) with pkgconfig(libadwaita-1)
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add e35dbc1acd03dd1751b755b6c8e1932a692ad4e1.patch: Fix build
  with meson 0.61.0 and newer.
* Fri Dec 10 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + Various fixes to timezone handling.
  + Updated translations.
* Fri Nov  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Fix Google Meet URL detection.
  + Updated translations.
- Update Supplements to current standard.
* Sat Sep 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Updated translations.
* Mon Sep  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc1:
  + Small cleanups.
  + Updated translations.
* Mon Aug 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.beta:
  + Implement opening ICS files and importing events
- Chnages from version 41.alpha:
  + Introduce the new event preview popover.
  + Updated translations.
* Fri Jun  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + Enable the met.no weather forecast provider.
  + Updated translations.
* Fri May 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Fix a memory leak in the timezone monitoring code.
  + Fix a crash when fetching the system timezone.
  + Fix keyboard shortcuts and add missing accelerator.
  + Fix multiday detection of all day events.
  + Updated translations.
* Tue Mar 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Wed Mar 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Minor cleanups.
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Use HdyViewSwitcher in the main window.
  + Fix the color of new calendars.
  + Updated translations.
* Tue Jan 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Depend on libhandy-1.
  + Port to the newer libgweather api.
  + Improve the event editor.
  + Updated translations.
- Replace pkgconfig(libhandy-0.0) BuildRequies with
  pkgconfig(libhandy-1): follow upstreams port to libhandy-1.
- Switch back to regular source tarballs.
* Thu Dec 17 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Never reset completed calendars.
  + Updated translations.
* Thu Dec 10 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Udpate to version 3.38.1+7:
  + gcal-timeline: never reset completed_calendars.
  + gcal-timeline: completed_calendars should be unsigned.
  + Updated translations.
- Switch to _service: upstream did not produce a 3.38.2 tarball,
  but 3.38.1 crashes, so we do want to move quicker.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Various fixes to the timeline.
  + Convert timezones when allocating on Week view.
* Thu Jun 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Week view now properly translates the event to the local
    timezone.
  + Properly commit sequence after event changes, and prevent data
    loss.
  + Fix first weekday calculation.
  + Updated translations.
* Thu Apr 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Introduce a new engine.
  + Fix a lot of bugs.
  + Support webcal:// URLs.
  + Updated translations.
- Add fdupes BuildRequires and macro call, remove duplicates.
* Sat Mar  7 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Updated translations.
* Sat Feb 29 2020 mgorse@suse.com
- Update to version 3.35.92:
  + Reorganize source code folders.
  + Redesigned event editor dialog.
  + Many other minor code cleanups.
  + Updated translations.
- Drop gnome-calendar-appid.patch: fixed upstream.
- Add libhandy to BuildRequires.
* Fri Feb 14 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.2:
  + New Nightly app icon.
  + Many code cleanups.
  + Updated translations.
- Add gnome-calendar-appid.patch: Fix app ID outside devel profile.
* Wed Oct  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Fix various crashers.
  + Updated translations.
* Sat Oct  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix various crashers.
  + Improve search results handling.
  + Make command line argument -d stand for --date.
  + Fix crashes when e_cal_util_get_system_timezone() returns NULL.
  + Fix first weekday calculation.
  + Remove g_get_current_time.
  + Readd <Ctrl>n shortcut.
  + Updated translations.
* Tue Sep 10 2019 qkzhu@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Tue Sep  3 2019 luke@ljones.dev
- Update to version 3.33.4:
  + Redesigned calendar management dialog.
  + New, more reliable web discoverer code.
  + Various bugfixes.
  + Updated translations.
  + Developer docs removed.
* Fri May 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Fix timezone handling of all day events.
* Sun Apr 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Fix release date field in AppData.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Fri Feb 15 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Fix build failures against latest EDS.
  + New app icon.
  + Rewrite timezone support for events.
  + Run nested EDS in Flatpak.
  + Updated translations.
- Add new check section to spec and run meson_test macro.
* Sat Nov  3 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Reimplement timezone management when editing events.
  + Updated translations.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
* Tue Aug 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Better handle 401 status codes when adding calendars.
  + Updated translations.
- Drop unneeded hicolor-icon-theme BuildRequires, use autosetup
  macro.
- Add gtk-doc BuildRequires and pass documentation=true instead of
  gtk-doc to meson, build documentation again.
- Pass tracing=false to meson ensure we build the package following
  upstream defaults.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Add Night Light integration.
  + Bugfixes.
* Wed May  2 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Don't show time labels on full day events.
  + Fix Week grid collapsing non-overlapping events.
  + Force timed events square box to be squared.
  + Use the correct end date on tooltips.
  + Minor improvements to the Month view paddings.
  + Fix a crash when deleting tasks.
  + Updates translations.
* Wed Apr 11 2018 luc14n0@linuxmail.org
- Update to version 3.28.1:
  + Updated translations.
- Drop desktop-file-utils BuildRequires: it is no longer required
  nor used anymore.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Flatpak improvements.
  + New unit tests.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb 12 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Big code refactorings that lead to more stability and ease of
    maintainership.
  + Follow-up improvements after rewritting the Month view.
  + Flatpak Nightly now builds with debug and tracing enabled.
  + Huge memory leaks were fixed.
  + Updated translations.
- Add pkgconfig(gweather-3.0), pkgconfig(libgeoclue-2.0) and
  pkgconfig(geocode-glib-1.0) BuildRequires: new dependencies.
* Mon Jan 22 2018 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Events now are rendered differently if they are all-day or
    timed.
  + Rewrite of the Month view:
  - Month cells have more transitions and effects.
  - The day number is above the cells.
  - A new overflow popup window was introduced.
  - Right-to-left languages are fully working now.
  + Plug some memory leaks.
  + Improve filename handling when adding new calendars.
  + Updated translations.
- Add libdazzle-1.0, libedataserverui-1.2 and libsoup-2.4
  pkgconfig BuildRequires: new dependencies.
- Drop pkgconfig(gmodule-export-2.0) and gtk-doc BuildRequires: the
  last is not needed since we don't build the documentation and the
  former is no longer used/needed anymore.
* Wed Jan 17 2018 luc14n0@linuxmail.org
- Update to version 3.26.3:
  + Fix time in tooltip text.
  + Fix timezones.
  + Updated translations.
* Thu Oct  5 2017 luc14n0@linuxmail.org
- Update to version 3.26.2:
  + Fixed many Flatpak issues.
  + Updated translations.
* Thu Sep 21 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Fix translations not being picked up.
  + Fix type race issue preventing correct initialization.
* Tue Sep 12 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Many fixes to recurrent events.
  + Cache events for better resource management.
  + Improve organization of files in the source code.
  + Handle command line options correctly.
  + Added the first version of a test suite. This will allow us
    continue improving and delivering new features with much less
    regressions.
  + Many code cleanups and reorganizations.
  + updated translations.
- Disable gtk-doc for now. Build fails (bgo#782150).
* Sat Sep  9 2017 jengelh@inai.de
- Update package summaries.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Port to Meson build system.
  + Improve string in the quick add popover.
  + Fix Month view's overflow detection.
  + Add support for adding and modifying recurrences.
  + Grey out out-of-range cells in Month view.
  + Move remaining files to GPLv3.
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Add gtk-doc and pass Denable-gtk-doc to meson: Build
  documentation, needed now that we are using meson buildsystem.
- Drop obsolete post(un) handling, remove following macros:
  + icon_theme_cache_post(un).
  + desktop_database_post(un).
  + glib2_gsettings_schema_post(un).
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Drop intltool.
  + Move events at column after remove event from list.
  + Hide search popover if click is performed outside.
  + Plug memory leaks.
  + Fix drag n' drop of multiday events in Week header.
  + Add margins to overflow label in Month view.
  + Properly format dates.
  + Fix crash when after closing Calendar.
  + Add recurrence dialog for modifying and removing recurrent
    events.
  + Updated translations.
- Drop intltool BuildRequires: no longer needed.
* Fri Jun  9 2017 firebird209@gmail.com
- Update to version 3.25.1:
  + Add developer documentation.
* Fri Jun  9 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + Fix date calculation in week header.
  + Plug many memory leaks.
  + Draw current time strip over events in Week view.
  + Reliably keep track of time with a new internal clocking API.
  + Add a new --debug option, to show debug messages.
  + Use libical2 to build Flatpak.
  + Improve Month view rendering code.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Fix crash in Week view.
  + Fix crash in changing the current date.
  + Properly update Week view's header when removing events.
  + Hide search popover when clicking outside it.
  + Updated translations.
* Fri Apr 28 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + Added logging capabilities.
  + Fix a lot of issues in Week view.
  + Big code cleanups in old classes.
  + Synchronize disabled calendars with Evolution.
  + Fix DnD cursor.
  + Optimize Year view.
  + Drop "Search..." app menu item.
  + Show tooltips when hovering event widgets.
  + Various memory leaks and fixups.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Fri Mar 17 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Fix first weekday in Week view.
  + Start searching after 3 characters.
  + Make sure calendar colors are in sync in Edit dialog.
  + Don't show search popover for empty searcher.
  + Minor fixups to Week view.
  + Updated translations.
* Tue Feb 28 2017 dimstar@opensuse.org
- Update to version 3.23.91.1:
  + Fix compiler flags.
  + Add the co-maintainer to the DOAP file.
* Tue Feb 28 2017 dimstar@opensuse.org
- Update to version 3.23.91:
  + Minor bugfixes.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Week view.
  + Improvements on the search popover.
  + Fix Year view not synchronized with Month view.
  + Correctly check if Edit dialog is editing a new event.
  + Improve focus tracking on the quick add popover.
  + Add a Flatpak manifest.
  + Align circle with subtitle in Edit dialog.
  + Updated translations.
* Mon Dec 19 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + Online calendars are now downloaded offline and synchronized.
  + Correctly draw the month view on mouse scroll.
  + A memory leaks was fixed.
  + Updated translations.
* Sun Oct  2 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Ablility to change months/years through mouse and touchpad
    scroll.
  + A huge number of bugfixes.
  + Many memory leaks were fixed.
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Fix compiler warning.
  + Fix various places to work with Gtk+ 3.21.6.
  + Forbid dragging read-only events.
  + Updated translations.
- Drop gnome-calendar-initialize-variable.patch: Fixed upstream.
* Wed Aug 31 2016 dimstar@opensuse.org
- Add gnome-calendar-initialize-variable.patch: Fix build on
  ppc64le by initializing the variable.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + New date chooser calendar.
  + Deprecate GNOME_COMPILE_WARNINGS.
  + Updated translations.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Share the 'show-weekdate' with GNOME Shell.
  + Fix issue in the calendar management dialog.
  + Add support for alarms.
  + Major updates on the edit dialog.
  + Style fixes and updates.
  + Fix year view popover positioning.
  + Updated translations.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires: New
  dependency.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Add the ability to change the month when navigating with
    keyboard.
  + Make the "Today" button insensitive when the current day is
    visible.
  + Keep the Sources dialog alive after closing it.
  + Adapt the CSS to Gtk+ 3.21 strictness.
  + Define the first week day in the build script.
  + Show all events of a month when clicking in the month name.
  + Vastly improve the Year view's navigator.
  + Correct the header capitalization.
  + Define ABOUT_NLS when configuring the project.
  + Fix various miscalculations in Month View.
  + Drop the usage of our custom .views CSS class.
  + Various GDateTime reference fixes.
  + Add Drag n' Drop capabilities to Month and Year View.
  + Updated translations.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Fix crashes.
  + Fix AM/PM selector not showing.
  + Updated translations.
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Revert some changes because of instabilities.
  + Use the theme's CSS instead of our custom one.
  + Fix the first week day detection.
  + Updated translations.
* Thu Apr 14 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Make Year view span multiple columns.
  + Fix issue on the Calendars dialog.
  + Fix crash on non GNOME Shell environments.
  + Fix untranslated strings.
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Don't attempt to update read-only events.
  + Timezone handling improvements.
  + Fix crashes when no end date is passed.
  + Improved week numbers in Year View.
  + Make year view respect Shell's 'show-weeknumber' setting.
  + Change month when keynav moves the previous/next month.
  + Improve month view drawing.
  + Draw a background to the selected days in month view.
  + Respect 12/24h hour format.
  + Fade out past events.
  + Smaller code fixes and updates.
  + Updated translations.
* Thu Mar  3 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Fixed tons of issues with timezones.
  + Style fixes.
  + Permanently remove the deleted event when closing the window.
  + Show start time of event when it's a timed event.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Many classes are now final classes.
  + Added visual clues for days with events on Year View.
  + Renamed icon to match the application id.
  + All interface elements that shows the calendar color are now
    updated accordingly.
  + A huge rework on Calendar internals.
  + Improved the quick add popover.
  + Added a keyboard shortcuts window.
  + Updated translations.
* Thu Jan 21 2016 zaitor@opensuse.org
- Update to version 3.19.4:
  + Code cleanups.
  + Use CSS names on classes.
  + Add kudos.
  + Make month view lines stronger.
  + Fix week number in year view.
  + Updated translations.
* Thu Dec 24 2015 damjanovic.ivo@gmail.com
- Update to version 3.19.3:
  + Window: split arrow buttons from Today button.
  + Create event popover: swap buttons' position.
  + Project: remove OnlyShowIn from desktop file.
  + Updated translations.
- Drop gnome-calendar-symbolic-icon.patch; fixed upstream.
- Drop gnome-common BuildRequires and call to autogen.sh, as we no
  longer carry any patches.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.18.2.1:
  + Revert string freeze break.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.18.2:
  + Remove OnlyShowIn from desktop file.
  + Bugs fixed: bgo#758730, bgo#756412, bgo#749337, bgo#755910,
    bgo#757931, bgo#758391.
  + Updated translations.
* Wed Nov  4 2015 zaitor@opensuse.org
- Add gnome-calendar-symbolic-icon.patch: Add symbolic icon.
* Sat Oct 17 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Mon Oct  5 2015 zaitor@opensuse.org
- Own %%dir %%{_datadir}/appdata for openSUSE Leap 42.1.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Mon Sep 14 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Wed Aug 19 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Updated translations.
* Tue Jul 21 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Fixed GNOME Calendar's category.
  + Added initial keyboard navigation for Month View.
  + Various code cleanups and fixes.
  + Updated translations.
* Thu Jun 25 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Misc bugfixes (bgo#751206, bgo#751209, bgo#751211, bgo#751244).
  + Updated translations.
* Wed May 27 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Added a calendar management dialog for creating, updating and
    deleting calendars.
  + When adding a new event, use current date as event start.
  + Updated translations.
- Add pkgconfig(goa-1.0) BuildRequires: New dependency.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix date related bug.
  + Fix app relaunching bug.
* Thu Apr 16 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Block creation on nameless events.
  + Updated translations.
* Wed Mar 25 2015 cdenicolo@suse.com
- license update: GPL-3.0+
  package is now licensed under GPL-3.0+
* Sat Mar 21 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Timezone handling fixes.
  + Bugs fixed: bgo#745117, bgo#745487.
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + search-view: set popover bottom position explicitly.
  + month-view: optimized event-widget parts removal.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Added gnome shell search provider.
- Create new subpackage gnome-shell-search-provider-gnome-calendar.
* Sun Jan 25 2015 badshah400@gmail.com
- Update to version 3.15.4.1:
  + Fix configure.ac distributed in package.
* Wed Jan 21 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Implemented new year-view.
  + Added initial working search.
  + Added appdata support for GNOME Software.
* Fri Dec 26 2014 badshah400@gmail.com
- Initial package.
